__author__: str
__license__: str
__version__: str

from rapidfuzz import (
    process as process,
    fuzz as fuzz,
    utils as utils,
    levenshtein as levenshtein,
    string_metric as string_metric,
)
